%% EBSD analysis with MTEX
% deformation structure vs. grain structure
% created for MTEX workshop 2018
% Wolfgang Pantleon 01.03.2018

clear variables;

% select inputfile from list
casename = 'W80asreceived';
%casename = 'W80recrystallized';
%casename = 'TP2asreceived';
%casename = 'TP1asreceived';
%casename = 'TP0.5asreceived';
%casename = 'TP0.2asreceived';

% Specify path to files
addpath(genpath('C:\Omicron\MTEX5\MTEXORCHID18\Data'));
addpath(genpath('C:\Omicron\MTEX5\MTEXORCHID18\Scripts'));

%% Part A1 Import of EBSD Data
% This script was automatically created by the import wizard. You should
% run the whoole script or parts of it in order to import your data. There
% is no problem in making any changes to this script.
% Specify Crystal and Specimen Symmetries

% crystal symmetry
CS = {... 
  'notIndexed',...
  crystalSymmetry('m-3m', [3.159 3.159 3.159], 'mineral', 'Tungsten', 'color', 'dark red')};

% Specify file names and conventions
% plotting convention (in general)
% might be overruled for specific files
setMTEXpref('xAxisDirection','east');
setMTEXpref('zAxisDirection','intoPlane');

switch casename
    case 'W80asreceived'
        fname = {...
            ['W80asrec_50Ap218DD20kV4-3nA500nmStSz_01.txt'],...
            };
        stepsize = 0.5; % not automatically saved in 'brukertxt'!!!
        % plotting convention
        setMTEXpref('xAxisDirection','west');
        setMTEXpref('zAxisDirection','outofPlane');
    case 'W80recrystallized'
        fname = {...
            ['W80asrec_50Ap218DD20kV4-3nA500nmStSz_01.txt'],...
            };
        stepsize = 2; % not automatically saved in 'brukertxt'!!!
    case 'TP2asreceived'
        fname = {...
            ['TP2_20kV50Ap4_3nA_100nm.txt'],...
            };
        stepsize = 0.1; % not automatically saved in 'brukertxt'!!!
    case 'TP1asreceived'
        fname = {...
            ['TP1_20kV50Ap4_3nA_100nm.txt'],...
            };
        stepsize = 0.1; % not automatically saved in 'brukertxt'!!!
    case 'TP0.5asreceived'
        fname = {...
            ['TP05_20kV50Ap4_3nA_100nm.txt'],...
            };
        stepsize = 0.1; % not automatically saved in 'brukertxt'!!!
    case 'TP0.2asreceived'
        fname = {...
            ['TP02_20kV50Ap4_3nA100nm20171101.txt'],...
            };
        stepsize = 0.1; % not automatically saved in 'brukertxt'!!!
end

% INPUT of EBSD file
ebsd = loadEBSD(fname,CS,'interface','brukertxt');
% determination of array size (requires integers)
% works in the manner only for brukertxt
xsteps = ebsd.prop.x(end)+1;
ysteps = ebsd.prop.y(end)+1;

% for other formats stepsize can be read from input
% and the number of steps determined
% stepsizex = ebsd.prop.x(2) - ebsd.prop.x(1); 
% stepsizey = ebsd.prop.y(end-1) - ebsd.prop.y(end); 
% if stepsizex == stepsizey
%       stepsize = stepsizex;
% end
% xsteps = floor((ebsd.prop.x(end)+1)/stepsizex);
% ysteps = floor((ebsd.prop.y(end)+1)/stepsizey);
% be aware of rounding errors!

stepunit = ebsd.scanUnit;
if stepunit == 'um'
    stepunit = '{\mu}m'; % done for MTEX figures automatically, but required for own figures
end

% General color definitions
gbcolor = [128, 128, 128]/255;      % grey for grain boundaries
corrbcolor = [240, 128, 128]/255;   % coral for correlated boundaries
allbcolor = [160, 82, 45]/255;      % sienna for correlated boundaries
% alternative color definition (same as in presentation)
% gbcolor = [255, 0, 255]/255;        % cyan for grain boundaries
% corrbcolor = [255, 0, 0]/255;       % red for correlated boundaries
% allbcolor = [128, 0, 0]/255;        % brown for correlated boundaries
firrcolor = [0, 0, 255]/255;
horcolor = [0, 0, 255]/255;
horfitcolor = [0, 255, 255]/255;
vercolor = [255, 0, 0]/255;
verfitcolor = [255, 0, 255]/255;
diacolor = [0, 255, 0]/255;

%% Part A2 Orientation map
% only for illustration
% Note that the scalebar is wrong due to a problem with 'brukertxt'

% plot(ebsd('t'),ebsd('t').orientations);

%% Part B1 prepare arrays for further use
% purpose: get orientation data for a specific phase
% on a rectangular array
% mark all other data with NaN
% create lists of specific phase

Qlisti = ebsd.phase;
Nebsd = size(Qlisti,1);
if Nebsd ~= xsteps*ysteps
    disp(['Identifed sizes do not match!']);
end
% setting non-indexed points to NaN
Qlisti = Qlisti + 0*Qlisti./Qlisti; 
% selecting a specific phase
Phasesel = 1;
NPhasesel = Nebsd;
for ilist = 1:Nebsd
    if Qlisti(ilist) ~= Phasesel
        NPhasesel = NPhasesel - 1;
        Qlisti(ilist) = 0/0;
    end
end

% mulitplying the phase filter
Qlista = ebsd.rotations.a.*Qlisti;
Qlistb = ebsd.rotations.b.*Qlisti;
Qlistc = ebsd.rotations.c.*Qlisti;
Qlistd = ebsd.rotations.d.*Qlisti;

% reshaping lists into maps
% reshaping with x as first coordinate and y as secon!
Qi = reshape(Qlisti,[xsteps, ysteps]);
Qa = reshape(Qlista,[xsteps, ysteps]);
Qb = reshape(Qlistb,[xsteps, ysteps]);
Qc = reshape(Qlistc,[xsteps, ysteps]);
Qd = reshape(Qlistd,[xsteps, ysteps]);

%% Part B2 create a random arrangement 
% of the same orientations on the same array
rng(01032018); % seed for preproducable results
newindex = rand(xsteps*ysteps,1);
newindex(1:xsteps*ysteps,2)=1:xsteps*ysteps;
newindex=sortrows(newindex,1);

Qrlisti = Qlisti(newindex(1:xsteps*ysteps,2));
Qrlista = Qlista(newindex(1:xsteps*ysteps,2));
Qrlistb = Qlistb(newindex(1:xsteps*ysteps,2));
Qrlistc = Qlistc(newindex(1:xsteps*ysteps,2));
Qrlistd = Qlistd(newindex(1:xsteps*ysteps,2));

Qri = reshape(Qrlisti,[xsteps, ysteps]);
Qra = reshape(Qrlista,[xsteps, ysteps]);
Qrb = reshape(Qrlistb,[xsteps, ysteps]);
Qrc = reshape(Qrlistc,[xsteps, ysteps]);
Qrd = reshape(Qrlistd,[xsteps, ysteps]);

% clear unncessary lists
clear Qlisti Qlista Qlistb Qlistc Qlistd Qrlisti Qrlista Qrlistb Qrlistc Qrlistd

%% Part C1 calculate disorientations with neighbors in different distances
% purpose: calculates individual disorientation angles with distant neighbors
% along horizontal and vertical direction
% disorientation angles are only kept in memory for next neighbors
% for distant neighbors only average and absolute frequencies are stored

% definition of different neighboring distances 
% short list of 16 distances (almost log) for efficiency
ddlist = [1 2 3 4 6 8 12 16 24 32 48 64 96 128 192 256];
% list for coloring with chosen colormap in Part E1
colorlist = [1 8 12 16 20 24 28 32 36 40 44 48 52 56 60 64];
mycolors = colormap('jet');
% definition of the last distance to be evaluated
ddlistmax = size(ddlist,2); % might be changed to a lower value (<=16)

% definition the bining for histograms
minangle = 0;
%maxangle = 62.8;  
maxangle = 63;  % to obtain simple edges for the individual bins, only cosmetics
nbin=63;
binwidth = (maxangle-minangle)/nbin;
edgelist = minangle + binwidth*(0:nbin);      % for command histcounts
centerlist = -minangle/2 + binwidth*(1:nbin); % for plotting purposes (one less than edges)

% calculation of the distant disorientation angles along horizontal
% direction (each call of distantdisorientation requires 1 s)
disp(['horizontal (wait ',num2str(ddlistmax,'%2.0d'),' s)']);
meandistanglex(1:ddlistmax) = 0;
hdistanglex(1:ddlistmax,1:nbin) = 0;
for ilist = 1:ddlistmax 
    ddx = ddlist(ilist);
    ddy = 0;
    [mdd, disoriangle] = distantdisorientation(Qa,Qb,Qc,Qd,ddx,ddy);
    if ilist == 1
        disorianglex = disoriangle;
    end
    meandistanglex(ilist) = mdd;
    hdistanglex(ilist,:) = histcounts(disoriangle,edgelist);
end
disorianglex = sort(disorianglex);
Ndisorix = size(disorianglex,1); 

% calculation of the distant disorientation angles along horizontal
% direction  (each call of distantdisorientation requires 1 s)
disp(['vertical (wait ',num2str(ddlistmax,'%2.0d'),' s)']);
meandistangley(1:ddlistmax) = 0;
hdistangley(1:ddlistmax,1:nbin) = 0;
for ilist = 1:ddlistmax
    ddx = 0;
    ddy = ddlist(ilist);
    [mdd, disoriangle] = distantdisorientation(Qa,Qb,Qc,Qd,ddx,ddy);
    if ilist == 1
        disoriangley=disoriangle;
    end
    meandistangley(ilist) = mdd;
    hdistangley(ilist,:) = histcounts(disoriangle,edgelist);
end
disoriangley = sort(disoriangley);
Ndisoriy = size(disoriangley,1);
disp('done');

%% Part C2 distant disorientation angles along diagonal directions
% the direction determined by dx=diagdir(1) and dy=diagdir(2)
% allows also negative and zero values
diagdir = [1 1];
% diagdir = [1 -1];
% diagdir = [2 1];
% diagdir = [1 2];
% diagdir = [2 -1];
% diagdir = [1 -2];
% (each call of distantdisorientation requires 1 s)

disp(['diagonal (wait ',num2str(ddlistmax,'%2.0d'),' s)']);
meandistanglexy(1:ddlistmax) = 0;
hdistanglexy(1:ddlistmax,1:nbin) = 0;
for ilist = 1:ddlistmax
    %disp(num2str(ilist));
    ddx = diagdir(1)*ddlist(ilist);
    ddy = diagdir(2)*ddlist(ilist);
    [mdd, disoriangle] = distantdisorientation(Qa,Qb,Qc,Qd,ddx,ddy);
    if ilist == 1
        disorianglexy = disoriangle;
    end
    meandistanglexy(ilist) = mdd;
    hdistanglexy(ilist,:) = histcounts(disoriangle,edgelist);
end
disorianglexy = sort(disorianglexy);
Ndisorixy = size(disorianglexy,1);
disp('done');

%% Part C3 calculation of the disorientations for the random case
% this corresponds to calculating the MODF from randomly chosen
% orientations. For each orientation in the set, the disorientation is calculated 
% with two other arbirarily chosen orientations.
% requires the random arrangement of Part B2
[Ra,Rb,Rc,Rd] = misorientation(Qra,Qrb,Qrc,Qrd,Qa,Qb,Qc,Qd);
dQ = disorientation(Ra,Rb,Rc,Rd);
disoriangler = 2* acosd(dQ);
disoriangler = disoriangler(disoriangler>=min(edgelist));
Ndisorir = size(disoriangler);
meandisangler = mean(disoriangler);
hdistangler = histcounts(disoriangler,edgelist);

%% Part C4 fitting of the mean disorientation angles in dependence on distance
% in horizontal and vertical direction to integrated functions corresponding
% to Rayleigh distributed chord length distributions 
% for either grain boundaries only (one Rayleigh)
% of deformation and grain boundaries (two Rayleigh)
% for mathematical background see
% [1] W. Pantleon, Unbiased evaluation of chord length distributions from orientation
%       maps, Mater. Sci. Forum 495-497 (2005) 219-224
% [2] W. Pantleon, Deformation structure versus grain structure after severe 
%       plastic deformation, Probl. Mater. Sci. 52 (2007) 13-23.

% fitting parametes
% 1 .. theta-irr                    irrelevant mean disorientation angle 
% 2 .. theta-corr - theta-irr       correlated mean disorientation angle
% 3 .. lambda-all                   average chord length between all boundaries
% 4 .. theta-uncorr - theta-corr    uncorrelated mean disorientation angle
% 5 .. lambda-uncorr                average chord length between grain boundaries
% chord lengths are in units of array and must still be multiplied by stepsize

% adapting options for lsqcurvefit
options = optimset('lsqcurvefit');
%val = optimget(options,'MaxFunEvals');
%val = optimget(options,'MaxIter');
optionsnew = optimset(options,'MaxFunEvals',2000,'MaxIter',1000,'TolFun',1e-10);

% fitting along horizontal
disoptistart = [1 40 5];
disoptix = lsqcurvefit(@cl1Rayleigh,disoptistart,ddlist,meandistanglex,[],[],optionsnew);
disoptiy = lsqcurvefit(@cl1Rayleigh,disoptistart,ddlist,meandistangley,[],[],optionsnew);
disoptistart2 = [0.5 5 5 35 30]; 
disoptix2 = lsqcurvefit(@cl2Rayleigh,disoptistart2,ddlist,meandistanglex,[],[],optionsnew);
if disoptix2(3) > disoptix2(5)
    disoptix2 = [disoptix2(1) disoptix2(4) disoptix2(5) disoptix2(2) disoptix2(3)];
end;
disoptiy2 = lsqcurvefit(@cl2Rayleigh,disoptistart2,ddlist,meandistangley,[],[],optionsnew);
if disoptiy2(3) > disoptiy2(5)
    disoptiy2 = [disoptiy2(1) disoptiy2(4) disoptiy2(5) disoptiy2(2) disoptiy2(3)];
end;

%% Part X1 dependence of fraction of low angle boundaries on step distance
% assumptions: boundaries are defined by by disorientation angles 
% above a certain threshold angle theta_threshold (e.g. 1)
theta_threshold = 1;
% usually a distinction is made between low angle boundaries (LAB) 
% with disorientation angles smaller than theta_crit = 15 omd
% high angle boundaries (HAB) 
theta_crit = 15;
% Find the fraction of low angle boundaries (of all boundaries) from
% the already calculated absoulte frequencies hdistanglex and hdistangley
% in dependence on the distance between neighbors and compare with the
% fraction of disorientations between theta_threshold and theta_crit of all
% disrientations equal are larger than theta_threshold for the
% disorientations between randomly chosen orientations (MODF).

% Note, the solution requires the absolute frequencies of disorientation angles
% with binning into bins of 1 obtained in Part C1

Nallboundx = sum(hdistanglex,2)-hdistanglex(:,1);
Nallboundy = sum(hdistangley,2)-hdistanglex(:,1);
NLABx = sum(hdistanglex(:,2:15),2);
NHABx = sum(hdistanglex(:,16:end),2);
NLABy = sum(hdistangley(:,2:15),2);
NHABy = sum(hdistangley(:,16:end),2);
NLAr = sum(hdistangler(2:15));
NHAr = sum(hdistangler(16:end));

figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(ddlist*stepsize,NLABx./(NLABx+NHABx),'>-','linewidth',2,'color',horcolor,'MarkerFacecolor',horcolor);
plot(ddlist*stepsize,NLABy./(NLABy+NHABy),'v-','linewidth',2,'color',vercolor,'MarkerFacecolor',vercolor);
plot([ddlist(1) ddlist(ddlistmax)]*stepsize,NLAr./(NLAr+NHAr)*[1 1],'k--','linewidth',2);
box on;
xlabel(['step distance / ',stepunit],'fontsize',16);
ylabel('fraction of low angle boundaries','fontsize',16);
legend({'horizontal (RD)','vertical (ND)','random'},'location','NE','fontsize',12);
axis([0 ddlist(ddlistmax)*stepsize 0 1]);

%% Part X2 Mean chord length between boundaries defined by threshold angle
% mean chord length (N_L)^(-1) determined as mean intercept length
% from intercept density N_L of horizontal or vertical lines with boundaries
% boundaries defined by a threshold for disorientation angle
theta_crit = 15;
% boundary density N_L = number of boundaries with angle above threshold / total area
%                      = (Ndisorix-n(disorientation > threshold)) * stepsize / Area;   


% Note, the solution requires the absolute frequencies of disorientation angles
% with binning into bins of 1 obtained in Part C1

% Note, that when calculating disorientation angles in larger distances
% than the step size of the map (e.g. a multiple n of the stepsize), 
% each "boundary" will be counted several times (n times) which must be
% corrected for!
NBcritx = sum(hdistanglex(:,theta_crit+1:end),2)'./ddlist;
NBcrity = sum(hdistangley(:,theta_crit+1:end),2)'./ddlist;

% Ahere = Nebsd;      % for total area of map
Ahere = NPhasesel;  % for the area occuspied by the selected phase
% one might correct for the outer boundaries / phase boundaries

figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(ddlist*stepsize,NBcritx/(Ahere*stepsize),'>-','linewidth',2,'color',horcolor,'MarkerFacecolor',horcolor);
plot(ddlist*stepsize,NBcrity/(Ahere*stepsize),'v-','linewidth',2,'color',vercolor,'MarkerFacecolor',vercolor);
box on;
xlabel(['step distance / ',stepunit],'fontsize',16);
ylabel(['Intercept density / ',stepunit,'^{-1}'],'fontsize',16);
title(['Intercept density HAB (boundaries with \theta\geq',num2str(theta_crit,'%2.0d'),'{\circ})']);
legend({'horizontal (RD)','vertical (ND)'},'location','NE','fontsize',12);

figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(ddlist*stepsize,Ahere*stepsize./NBcritx,'>-','linewidth',2,'color',horcolor,'MarkerFacecolor',horcolor);
plot(ddlist*stepsize,Ahere*stepsize./NBcrity,'v-','linewidth',2,'color',vercolor,'MarkerFacecolor',vercolor);
plot([0 ddlist(ddlistmax)]*stepsize,[0 ddlist(ddlistmax)]*stepsize,'k--','linewidth',2,'MarkerFacecolor','r');
box on;
xlabel(['step distance / ',stepunit],'fontsize',16);
ylabel(['mean chord length / ',stepunit],'fontsize',16);
title(['Mean chord length of HAB (boundaries with \theta\geq',num2str(theta_crit,'%2.0d'),'{\circ})']);
legend({'horizontal (RD)','vertical (ND)'},'location','NW','fontsize',12);
axis([0 15 0 30]);

%% Part D1 evaluation of mean chord length in dependence of threshold angle 
% mean chord length (N_L)^(-1) determined as mean intercept length
% from intercept density N_L of horizontal or vertical lines with boundaries
% boundaries defined by a threshold for disorientation angle
% boundary density N_L = number of boundaries with angle above threshold / total area
%                      = (Ndisorix-n(disorientation > threshold)) * stepsize / Area;   

figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(disorianglex,xsteps*ysteps*stepsize./(Ndisorix-(1:Ndisorix)),'-','linewidth',2','color',horcolor);
plot(disoriangley,xsteps*ysteps*stepsize./(Ndisoriy-(1:Ndisoriy)),'-','linewidth',2','color',vercolor);
plot([0 63],[1 1]*stepsize,'k:','linewidth',2');
plot([15 15],[0 50],'k--','linewidth',2);
box on;
xlabel('threshold angle /{\circ}','fontsize',16); 
ylabel(['mean chord length / ',stepunit],'fontsize',16);
title(['Mean chord length evaluated with map step size']);
axis([0 64 0 30]);
legend({'horizontal (RD)','vertical (ND)','map step size'},'location','N','fontsize',12);

%% Part D2 mean disorientation angle vs. step distance without fit
figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(ddlist*stepsize,meandistanglex,'>-','linewidth',2,'color',horcolor,'MarkerFacecolor',horcolor);
plot(ddlist*stepsize,meandistangley,'v-','linewidth',2,'color',vercolor,'MarkerFacecolor',vercolor);
plot(ddlist*stepsize*norm(diagdir),meandistanglexy,'d--','linewidth',2,'color',diacolor,'MarkerFacecolor',diacolor);
plot([ddlist(1) ddlist(ddlistmax)]*stepsize,meandisangler*[1 1],'k--','linewidth',2);
box on;
xlabel(['step distance / ',stepunit],'fontsize',16);
ylabel('mean disorientation angle /{\circ}','fontsize',16);
title(['Mean disorientation angle depending on step distance']);
legend({'horizontal (RD)','vertical (ND)', ...
    ['diagonal [',num2str(diagdir(1),'%1.0d'),' ',num2str(diagdir(2),'%1.0d'),']']},'location','SE','fontsize',12);
axis([0 ddlist(ddlistmax)*stepsize 0 45]);

%% Part X3 Anisotropy along different diagonal directions (qualitatively)
% Explore the direction dependence of the mean disorientation angle dependence
% Repeat C2 for different directions diagdir and plot with D2 
% Compare the obtained results along different directions

%% Part D3 mean disorientation angle vs. step distance with fit of one Rayleigh 
% requires fits from Part C4
figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(ddlist*stepsize,meandistanglex,'>','linewidth',2,'color',horcolor,'MarkerFacecolor',horcolor);
plot(ddlist*stepsize,meandistangley,'v','linewidth',2,'color',vercolor,'MarkerFacecolor',vercolor);
%plot(ddlist*norm(diagdir),meandistanglexy,'gd--','linewidth',2,'MarkerFacecolor','g');
plot((0:ddlist(ddlistmax))*stepsize,cl1Rayleigh(disoptix,0:ddlist(ddlistmax)),'-','linewidth',2,'color',horfitcolor);
plot((0:ddlist(ddlistmax))*stepsize,cl1Rayleigh(disoptiy,0:ddlist(ddlistmax)),'-','linewidth',2,'color',verfitcolor);
plot([ddlist(1) ddlist(ddlistmax)]*stepsize,meandisangler*[1 1],'k--','linewidth',2);
box on;
xlabel(['step distance / ',stepunit],'fontsize',16);
ylabel('mean disorientation angle /{\circ}','fontsize',16);
title('Fit \theta_{irr} \theta_{uncorr} {\it l}_{uncorr}');
legend({'horizontal (RD)','vertical (ND)',...
    [num2str(disoptix(1),'%3.1f'),'{\circ} ',...
    num2str(disoptix(1)+disoptix(2),'%3.1f'),'{\circ} ', ...
    num2str(disoptix(3)*stepsize,'%3.1f'),' {\mu}m'], ...
    [num2str(disoptiy(1),'%3.1f'),'{\circ} ',...
    num2str(disoptiy(1)+disoptiy(2),'%3.1f'),'{\circ} ', ...
    num2str(disoptiy(3)*stepsize,'%3.1f'),' {\mu}m']}, ...
    'location','SE','fontsize',12);
axis([0 ddlist(ddlistmax)*stepsize 0 45]);
% Note, legend creates proper values mentioned in title

%% Part D4 mean disorientation angle vs. step distance with fit of two Rayleighs
% requires fits from Part C4
figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(ddlist*stepsize,meandistanglex,'>','linewidth',2,'color',horcolor,'MarkerFacecolor',horcolor);
plot(ddlist*stepsize,meandistangley,'v','linewidth',2,'color',vercolor,'MarkerFacecolor',vercolor);
%plot(ddlist*norm(diagdir),meandistanglexy,'gd--','linewidth',2,'MarkerFacecolor','g');
plot((0:ddlist(ddlistmax))*stepsize,cl2Rayleigh(disoptix2,0:ddlist(ddlistmax)),'-','linewidth',2,'color',horfitcolor);
plot((0:ddlist(ddlistmax))*stepsize,cl2Rayleigh(disoptiy2,0:ddlist(ddlistmax)),'-','linewidth',2,'color',verfitcolor);
plot((0:ddlist(ddlistmax))*stepsize,cl1Rayleigh(disoptix,0:ddlist(ddlistmax)),'--','linewidth',2,'color',horfitcolor);
plot((0:ddlist(ddlistmax))*stepsize,cl1Rayleigh(disoptiy,0:ddlist(ddlistmax)),'--','linewidth',2,'color',verfitcolor);
plot([ddlist(1) ddlist(ddlistmax)]*stepsize,meandisangler*[1 1],'k--','linewidth',2);
box on;
xlabel(['step distance / ',stepunit],'fontsize',16);
ylabel('mean disorientation angle /{\circ}','fontsize',16);
title('Fit \theta_{irr} \theta_{corr} {\it l}_{all} \theta_{uncorr} {\it l}_{uncorr}');
%legend({'horizontal (RD)','vertical (ND)','diagonal'},'location','SE','fontsize',12);
legend({'horizontal (RD)','vertical (ND)',...
    [num2str(disoptix2(1),'%3.1f'),'{\circ} ',...
    num2str(disoptix2(1)+disoptix2(2),'%3.1f'),'{\circ} ', ...
    num2str(disoptix2(3)*stepsize,'%3.1f'),' {\mu}m ', ...
    num2str(disoptix2(1)+disoptix2(2)++disoptix2(4),'%3.1f'),'{\circ} ', ...
    num2str(disoptix2(5)*stepsize,'%3.1f'),' {\mu}m'], ...
    [num2str(disoptiy2(1),'%3.1f'),'{\circ} ',...
    num2str(disoptiy2(1)+disoptiy2(2),'%3.1f'),'{\circ} ', ...
    num2str(disoptiy2(3)*stepsize,'%3.1f'),' {\mu}m ', ...
    num2str(disoptiy2(1)+disoptiy2(2)+disoptiy2(4),'%3.1f'),'{\circ} ', ...
    num2str(disoptiy2(5)*stepsize,'%3.1f'),' {\mu}m']}, ...
    'location','SE','fontsize',12);
axis([0 ddlist(ddlistmax)*stepsize 0 45]);
% Note, legend creates proper values mentioned in title

%% Part X4 Relevant and irrelevant fractions
% The fits to the mean disorientation angle in dependence on step distance
% result in a quantitative description of the different relevant fractions
% correspoding to all boundaries, correlated boundaries, uncorrelated
% boundaries and the irrelevant fraction. Plot this different fractions 
% for the horizontal and the vertical direction. 

% horizontal direction
figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
xiallx = cl2Rayleigh([0,1,disoptix2(3),0,disoptix2(5)],(0:ddlist(ddlistmax)));
xigbx = cl2Rayleigh([0,0,disoptix2(3),1,disoptix2(5)],(0:ddlist(ddlistmax)));
plot((0:ddlist(ddlistmax))*stepsize,xiallx,'-','linewidth',2,'color',allbcolor,'MarkerFacecolor',allbcolor);
plot((0:ddlist(ddlistmax))*stepsize,xigbx,'-','linewidth',2,'color',gbcolor,'MarkerFacecolor',gbcolor);
plot((0:ddlist(ddlistmax))*stepsize,xiallx-xigbx,'-','linewidth',2,'color',corrbcolor,'MarkerFacecolor',corrbcolor);
plot((0:ddlist(ddlistmax))*stepsize,1-xiallx,'-','linewidth',2,'color',firrcolor,'MarkerFacecolor',firrcolor);
box on;
xlabel(['chord length / ',stepunit],'fontsize',16);
ylabel('fraction','fontsize',16);
title('Relevant and irrelevant fractions (horizontal)');
legend({['all boundaries      ',num2str(disoptix2(3)*stepsize,'%3.1f'),' {\mu}m'], ...
    ['grain boundaries ',num2str(disoptix2(5)*stepsize,'%3.1f'),' {\mu}m'], ...
    ['deformation boundaries '], ...
    ['irrelevant']}, ...
    'location','E','fontsize',12);
axis([0 ddlist(ddlistmax)*stepsize/2 0 1]);

% vertical direction
figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
xially = cl2Rayleigh([0,1,disoptiy2(3),0,disoptiy2(5)],(0:ddlist(ddlistmax)));
xigby = cl2Rayleigh([0,0,disoptiy2(3),1,disoptiy2(5)],(0:ddlist(ddlistmax)));
plot((0:ddlist(ddlistmax))*stepsize,xially,'-','linewidth',2,'color',allbcolor,'MarkerFacecolor',allbcolor);
plot((0:ddlist(ddlistmax))*stepsize,xigby,'-','linewidth',2,'color',gbcolor,'MarkerFacecolor',gbcolor);
plot((0:ddlist(ddlistmax))*stepsize,xially-xigby,'-','linewidth',2,'color',corrbcolor,'MarkerFacecolor',corrbcolor);
plot((0:ddlist(ddlistmax))*stepsize,1-xially,'-','linewidth',2,'color',firrcolor,'MarkerFacecolor',firrcolor);
box on;
xlabel(['chord length / ',stepunit],'fontsize',16);
ylabel('fraction','fontsize',16);
title('Relevant and irrelevant fractions (vertical)');
legend({['all boundaries      ',num2str(disoptiy2(3)*stepsize,'%3.1f'),' {\mu}m'], ...
    ['grain boundaries ',num2str(disoptiy2(5)*stepsize,'%3.1f'),' {\mu}m'], ...
    ['deformation boundaries '], ...
    ['irrelevant']}, ...
    'location','E','fontsize',12);
axis([0 ddlist(ddlistmax)*stepsize/2 0 1]);

%% Part E1 Disorientation angle distributions for selected step distances
% colors are defined in Part C1
% displaylist = 1:ddlistmax; % gives usually to many lines
% therefore restriction to a few selected
displaylist = [1 2 4 6 8 10 12 16];

% binrange allows to restrict angle range
% binrange = 1:nbin;    % all bins
binrange = 2:nbin;      % eliminates first bin (theta_threshold = 1) 
%binrange = 4:nbin;      % eliminates first bin (theta_threshold = 1) 

figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(centerlist,hdistangler/sum(hdistangler)/binwidth,'k-','linewidth',2);
for ilist = displaylist
    plot(centerlist(binrange),hdistanglex(ilist,binrange)/sum(hdistanglex(ilist,binrange))/binwidth,'-','color',mycolors(colorlist(ilist),:),'linewidth',2);
end
plot([1 1],[0 1],'k:','linewidth',2');
box on;
xlabel('disorientation angle /{\circ}');
ylabel('probability density');
title('disorientation angle distribution (horizontal)');
legend({'random', ...
    [num2str(ddlist(displaylist(1))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(2))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(3))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(4))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(5))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(6))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(7))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(8))),' {\Delta}x'] ...
%     , [num2str(ddlist(displaylist(9))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(10))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(11))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(12))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(13))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(14))),' {\Delta}x'], ...
    },'location','N');
axis([0 64 0 0.05]);

figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(centerlist,hdistangler/sum(hdistangler)/binwidth,'k-','linewidth',2);
for ilist = displaylist
    plot(centerlist(binrange),hdistangley(ilist,binrange)/sum(hdistangley(ilist,binrange))/binwidth,'-','color',mycolors(colorlist(ilist),:),'linewidth',2);
end
plot([1 1],[0 1],'k:','linewidth',2');
box on;
xlabel('disorientation angle /{\circ}');
ylabel('probability density');
title('disorientation angle distribution (vertical)');
legend({'random', ...
    [num2str(ddlist(displaylist(1))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(2))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(3))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(4))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(5))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(6))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(7))),' {\Delta}x'], ...
    [num2str(ddlist(displaylist(8))),' {\Delta}x'] ...
%     , [num2str(ddlist(displaylist(9))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(10))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(11))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(12))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(13))),' {\Delta}x'], ...
%     [num2str(ddlist(displaylist(14))),' {\Delta}x'], ...
    },'location','N');axis([0 64 0 0.05]);

%% Part E2 Separation of distributions from deformation boundaries and grain boundaries
% starting point two distributions with different ddx or ddy
ilistselx1 = 6;
ilistselx2 = 12;
ilistsely1 = 6;
ilistsely2 = 12;

% horizontal direction
% fractions of the different types of boundaries
% each obtained from double integrated Rayleigh
% fraction of all boundaries
xiall1=cl2Rayleigh([0,1,disoptix2(3),0,disoptix2(5)],ddlist(ilistselx1));
xiall2=cl2Rayleigh([0,1,disoptix2(3),0,disoptix2(5)],ddlist(ilistselx2));
% fraction of grain boundaries (uncorrelated boundaries)
xigb1=cl2Rayleigh([0,0,disoptix2(3),1,disoptix2(5)],ddlist(ilistselx1));
xigb2=cl2Rayleigh([0,0,disoptix2(3),1,disoptix2(5)],ddlist(ilistselx2));
% fraction of deformation boundaries (correlated boundaries)
xidef1=xiall1-xigb1;
xidef2=xiall2-xigb2;
% proper relative fractions (deformation and grain bound. ignoring irrelevant fraction)
xidef1=xidef1/xiall1;
xidef2=xidef2/xiall2;
xigb1=xigb1/xiall1;
xigb2=xigb2/xiall2;

% probability densities of selected distances
hnormsel1 = hdistanglex(ilistselx1,:)/sum(hdistanglex(ilistselx1,:))/binwidth;
hnormsel2 = hdistanglex(ilistselx2,:)/sum(hdistanglex(ilistselx2,:))/binwidth;
% probability densities for both boundary types (see [1,2])
hnormgb = (xidef2*hnormsel1-xidef1*hnormsel2)/(xidef2*xigb1-xidef1*xigb2);
hnormdef= (xigb2*hnormsel1-xigb1*hnormsel2)/(xigb2*xidef1-xigb1*xidef2);

figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(centerlist,hnormsel1,'-','linewidth',2,'color',mycolors(colorlist(ilistselx1),:));
plot(centerlist,hnormsel2,'-','linewidth',2,'color',mycolors(colorlist(ilistselx2),:));
plot(centerlist,hnormgb*xigb1,'-','linewidth',2,'color',gbcolor);
plot(centerlist,hnormdef*xidef1,'-','linewidth',2,'color',corrbcolor);
plot(centerlist,-hnormdef*xidef1,'--','linewidth',2,'color',corrbcolor);
plot(centerlist,hdistangler/sum(hdistangler)/binwidth,'k-','linewidth',2);
plot([1 1],[0 1],'k:','linewidth',2');
ymax = 0.05;
plot([minangle minangle],[0 ymax],'k--','Linewidth',2);
xlabel('disorientation angle /{\circ}','fontsize',18,'fontweight','demi');
ylabel('probability density','fontsize',18,'Fontweight','demi');
title('disorientation angle distribution (horizontal)');
legend({['{\Delta}x/{x_0}=',num2str(ddlist(ilistselx1),'%3.0d')],...
    ['{\Delta}x/{x_0}=',num2str(ddlist(ilistselx2),'%3.0d')],...
    'grains','deformation','(-) deformation','randomized'},'location','N');
axis([0 64 0 ymax]);
box on;

% Note that variables will be re-used, potential cause of failure
% vertical direction
% fractions of the different types of boundaries
% each obtained from double integrated Rayleigh
% fraction of all boundaries
xiall1=cl2Rayleigh([0,1,disoptiy2(3),0,disoptiy2(5)],ddlist(ilistsely1));
xiall2=cl2Rayleigh([0,1,disoptiy2(3),0,disoptiy2(5)],ddlist(ilistsely2));
% fraction of grain boundaries (uncorrelated boundaries)
xigb1=cl2Rayleigh([0,0,disoptiy2(3),1,disoptiy2(5)],ddlist(ilistsely1));
xigb2=cl2Rayleigh([0,0,disoptiy2(3),1,disoptiy2(5)],ddlist(ilistsely2));
% fraction of deformation boundaries (correlated boundaries)
xidef1=xiall1-xigb1;
xidef2=xiall2-xigb2;
% proper relative fractions (deformation and grain bound. ignoring irrelevant fraction)
xidef1=xidef1/xiall1;
xidef2=xidef2/xiall2;
xigb1=xigb1/xiall1;
xigb2=xigb2/xiall2;

% probability densities of selected distances
hnormsel1 = hdistangley(ilistsely1,:)/sum(hdistangley(ilistsely1,:))/binwidth;
hnormsel2 = hdistangley(ilistsely2,:)/sum(hdistangley(ilistsely2,:))/binwidth;
% probability densities for both boundary types (see [1,2])
hnormgb = (xidef2*hnormsel1-xidef1*hnormsel2)/(xidef2*xigb1-xidef1*xigb2);
hnormdef= (xigb2*hnormsel1-xigb1*hnormsel2)/(xigb2*xidef1-xigb1*xidef2);

figure; hold on;
set(gca,'fontsize',12,'fontweight','demi','linewidth',2);
plot(centerlist,hnormsel1,'-','color',mycolors(colorlist(ilistsely1),:),'linewidth',2);
plot(centerlist,hnormsel2,'-','color',mycolors(colorlist(ilistsely2),:),'linewidth',2);
plot(centerlist,hnormgb*xigb1,'-','linewidth',2,'color',gbcolor);
plot(centerlist,hnormdef*xidef1,'-','linewidth',2,'color',corrbcolor);
plot(centerlist,-hnormdef*xidef1,'--','linewidth',2,'color',corrbcolor);
plot(centerlist,hdistangler/sum(hdistangler)/binwidth,'k-','linewidth',2);
plot([1 1],[0 1],'k:','linewidth',2');
ymax = 0.05;
plot([minangle minangle],[0 ymax],'k--','Linewidth',2);
xlabel('disorientation angle /{\circ}','fontsize',18,'fontweight','demi');
ylabel('probability density','fontsize',18,'Fontweight','demi');
title('disorientation angle distribution (vertical)');
legend({['{\Delta}x/{x_0}=',num2str(ddlist(ilistsely1),'%3.0d')],...
    ['{\Delta}x/{x_0}=',num2str(ddlist(ilistsely2),'%3.0d')],...
    'grains','deformation','(-) deformation','randomized'},'location','N');
axis([0 64 0 ymax]);
box on;

%% Part X5 Separation by selecting two distributions of different step distances
% For the separation along the vertical direction in the part above,
% two specific distributions were selected corresponding to 8 and 64 times the step size 
% (ilistsely1 = 6 and ilistsely2 = 12) 
% Explore the effect of the selected distributions by chosing different
% values for ilistsely1 and ilistsely2 in F2

%% Part X6 Anisotropy along different diagonal directions (quantitatively)
% Explore the direction dependence of the mean disorientation angle dependence
% Repeat C2 for different directions diagdir and plot with D2 
% Analyze the results by fitting with two Rayleigh distributions similar to D4
% Investigate the orientation dependence of the mean chord length
% for the two different types of boundaries 
